@@ -11,15 +11,15 @@ class SegmenterParameters(BaseModel):
 
 
 class SegmenterBase(metaclass=ABCSingleton):
-    """Base class for example plugin used in the tutorial.
-    """
+    """Base class for example plugin used in the tutorial."""
 
     def __init__(self):
         pass
 
     @abc.abstractmethod
-    def segment(self, documents: List[Document], options: SegmenterParameters) \
-            -> List[Document]:
+    def segment(
+        self, documents: List[Document], options: SegmenterParameters
+    ) -> List[Document]:
         """Segment the input documents and return the modified documents.
 
         :param documents: A list of annotated documents.
